import React, { useState, useMemo, useEffect } from 'react'
import { Select, message, Tag, options, TreeSelect   } from 'antd'
import { getSiteTree, getStationIDListByUserID } from '../../../../../apis/process'

const SiteSelect = props => {
    const userID = window?.globalConfig?.userInfo?.OID || 1
    const { value, onChange, schema, addons } = props
    const {
      placeholder,
      disabled,
      formDisabled,
      sourceType,
      options,
      dictionary,
      tableName,
      fieldName,
      presetValue,
      isMultiple,
      isEdit,
      isMySite,
      isSearch,
      isStoreID,
      color
    } = schema
    const { SHOW_PARENT } = TreeSelect;
    const [siteTree, setSiteTree] = useState([]);
    useEffect(()=>{
        getStation();
    }, [])
    
  const getStation = async () => {
    const { code, data, msg } = await getSiteTree()
    if (code === 0) {
      if (Array.isArray(data.list)) {
        const sites =  mapTree(data.list);
        console.log(sites, '树形结构数据');
        setSiteTree(sites);
      } else {
        setSiteTree([])
      }
    } else {
      message.error(msg)
    }
  }

  const mapTree = (sites = [])=>{
    let list = [];
    sites.forEach(site=> {
      list.push({
        title: site.text,
        key: site.id,
        value: site.id,
        children: site.children && site.children.length > 0 ?  mapTree(site.children) : []
      })
    })
    return list;
  }
  const tProps = {
    allowClear: true,
    treeData: siteTree,
    onChange,
    value,
    treeCheckable: true,
    showCheckedStrategy: TreeSelect.SHOW_ALL,
    placeholder: '配置站点选择范围',
    style: {
      width: '100%',
    },
  };
  return <TreeSelect {...tProps} />;

}

export default SiteSelect